Welcome to Cosinnus' documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2
    
   initial_setup
   api
   attachments
   authentication
   export
   hierarchy
   permissions
   templatetags
   ref/cosinnus


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

